@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2002,2003 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 2002-2004 Erik de Castro Lopo <erikd@mega-nerd.com>
 ** Copyright (C) 2003 Ross Bencina <rbencina@iprimus.com.au>
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -431,7 +431,7 @@ psf_log_syserr (SF_PRIVATE *psf, int error)
 	/* Only log an error if no error has been set yet. */
 	if (psf->error == 0)
 	{	psf->error = SFE_SYSTEM ;
-		LSF_SNPRINTF (psf->syserr, sizeof (psf->syserr), "System error : %s", strerror (error)) ;
+		LSF_SNPRINTF (psf->syserr, sizeof (psf->syserr), "System error : %s.", strerror (error)) ;
 		} ;
 
 	return ;
@@ -449,7 +449,7 @@ psf_log_syserr (SF_PRIVATE *psf, int error)
 #include <io.h>
 
 #ifndef HAVE_SSIZE_T
-typedef int ssize_t ;
+typedef long ssize_t ;
 #endif
 
 /* Win32 */ static void
@@ -559,7 +559,12 @@ psf_set_stdio (SF_PRIVATE *psf, int mode)
 
 /* Win32 */ void
 psf_set_file (SF_PRIVATE *psf, int fd)
-{	psf->filedes = _get_osfhandle (fd) ;
+{	HANDLE temp = _get_osfhandle (fd) ;
+
+	if (GetFileType (temp) == FILE_TYPE_DISK)
+		psf->filedes = (int) temp ;
+	else
+		psf->filedes = fd ;
 } /* psf_set_file */
 
 /* Win32 */ int
@@ -765,14 +770,12 @@ psf_is_pipe (SF_PRIVATE *psf)
 /* Win32 */ sf_count_t
 psf_get_filelen (SF_PRIVATE *psf)
 {	sf_count_t filelen ;
-	DWORD dwFileSizeLow, dwFileSizeHigh, dwError ;
+	DWORD dwFileSizeLow, dwFileSizeHigh, dwError = NO_ERROR ;
 
 	dwFileSizeLow = GetFileSize ((HANDLE) psf->filedes, &dwFileSizeHigh) ;
 
 	if (dwFileSizeLow == 0xFFFFFFFF)
 		dwError = GetLastError () ;
-	else
-		dwError = NO_ERROR ;
 
 	if (dwError != NO_ERROR)
 	{	psf_log_syserr (psf, GetLastError ()) ;
@@ -811,7 +814,7 @@ psf_get_filelen (SF_PRIVATE *psf)
 psf_ftruncate (SF_PRIVATE *psf, sf_count_t len)
 {	int retval = 0 ;
 	LONG lDistanceToMoveLow, lDistanceToMoveHigh ;
-	DWORD dwResult, dwError ;
+	DWORD dwResult, dwError = NO_ERROR ;
 
 	/* This implementation trashes the current file position.
 	** should it save and restore it? what if the current position is past
@@ -870,7 +873,7 @@ psf_ftruncate (SF_PRIVATE *psf, sf_count_t len)
 #include <direct.h>
 
 #ifndef HAVE_SSIZE_T
-typedef int ssize_t ;
+typedef long ssize_t ;
 #endif
 
 /* Win32 */ int
