@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2002 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 2001-2004 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -578,7 +578,7 @@ truncate_test (const char *filename, int filetype)
 
 	len = 100 ;
 	if (sf_command (file, SFC_FILE_TRUNCATE, &len, sizeof (len)))
-	{	printf ("Line %d: sf_command (SFC_FILE_TRUNCATE) returned error.\n", __LINE__) ;
+	{	printf ("\n\nLine %d: sf_command (SFC_FILE_TRUNCATE) returned error : %s\n\n", __LINE__, sf_strerror (file)) ;
 		exit (1) ;
 		} ;
 
